@@ -4,7 +4,7 @@ package ansi
 
 import "github.com/jandedobbeleer/oh-my-posh/src/platform"
 
-func GetAccentColor(env platform.Environment) (*RGB, error) {
+func GetAccentColor(_ platform.Environment) (*RGB, error) {
 	return nil, &platform.NotImplemented{}
 }
 
@@ -13,7 +13,7 @@ func (d *DefaultColors) SetAccentColor(env platform.Environment, defaultColor st
 		return
 	}
 	d.accent = &Colors{
-		Foreground: string(d.ToColor(defaultColor, false)),
-		Background: string(d.ToColor(defaultColor, true)),
+		Foreground: string(d.ToColor(defaultColor, false, env.Flags().TrueColor)),
+		Background: string(d.ToColor(defaultColor, true, env.Flags().TrueColor)),
 	}
 }
