@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"math"
+	"net/url"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
@@ -28,10 +29,6 @@ const (
 	Location properties.Property = "location"
 	// Units openweathermap units
 	Units properties.Property = "units"
-	// Latitude for the location used in place of location
-	Latitude properties.Property = "latitude"
-	// Longitude for the location used in place of location
-	Longitude properties.Property = "longitude"
 	// CacheKeyResponse key used when caching the response
 	CacheKeyResponse string = "owm_response"
 	// CacheKeyURL key used when caching the url responsible for the response
@@ -54,11 +51,6 @@ type owmDataResponse struct {
 	temperature `json:"main"`
 }
 
-type geoLocation struct {
-	Lat float64 `json:"lat"`
-	Lon float64 `json:"lon"`
-}
-
 func (d *Owm) Enabled() bool {
 	err := d.setStatus()
 
@@ -77,65 +69,37 @@ func (d *Owm) Template() string {
 func (d *Owm) getResult() (*owmDataResponse, error) {
 	cacheTimeout := d.props.GetInt(properties.CacheTimeout, properties.DefaultCacheTimeout)
 	response := new(owmDataResponse)
+
 	if cacheTimeout > 0 {
-		// check if data stored in cache
 		val, found := d.env.Cache().Get(CacheKeyResponse)
-		// we got something from te cache
 		if found {
 			err := json.Unmarshal([]byte(val), response)
 			if err != nil {
 				return nil, err
 			}
+
 			d.URL, _ = d.env.Cache().Get(CacheKeyURL)
 			return response, nil
 		}
 	}
 
-	apikey := properties.OneOf[string](d.props, ".", APIKey, "apiKey")
+	apikey := properties.OneOf(d.props, ".", APIKey, "apiKey")
 	if len(apikey) == 0 {
 		apikey = d.env.Getenv(PoshOWMAPIKey)
 	}
 
-	if len(apikey) == 0 {
-		return nil, errors.New("no api key found")
+	location := d.props.GetString(Location, "De Bilt,NL")
+
+	location = url.QueryEscape(location)
+
+	if len(apikey) == 0 || len(location) == 0 {
+		return nil, errors.New("no api key or location found")
 	}
 
-	location := d.props.GetString(Location, "De Bilt,NL")
-	latitude := d.props.GetFloat64(Latitude, 91)    // This default value is intentionally invalid since there should not be a default for this and 0 is a valid value
-	longitude := d.props.GetFloat64(Longitude, 181) // This default value is intentionally invalid since there should not be a default for this and 0 is a valid value
 	units := d.props.GetString(Units, "standard")
 	httpTimeout := d.props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout)
 
-	validCoordinates := func(latitude, longitude float64) bool {
-		// Latitude values are only valid if they are between -90 and 90
-		// Longitude values are only valid if they are between -180 and 180
-		// https://gisgeography.com/latitude-longitude-coordinates/
-		return latitude <= 90 && latitude >= -90 && longitude <= 180 && longitude >= -180
-	}
-
-	if !validCoordinates(latitude, longitude) {
-		var geoResponse []geoLocation
-		geocodingURL := fmt.Sprintf("http://api.openweathermap.org/geo/1.0/direct?q=%s&limit=1&appid=%s", location, apikey)
-
-		body, err := d.env.HTTPRequest(geocodingURL, nil, httpTimeout)
-		if err != nil {
-			return new(owmDataResponse), err
-		}
-
-		err = json.Unmarshal(body, &geoResponse)
-		if err != nil {
-			return new(owmDataResponse), err
-		}
-
-		if len(geoResponse) == 0 {
-			return new(owmDataResponse), fmt.Errorf("no coordinates found for %s", location)
-		}
-
-		latitude = geoResponse[0].Lat
-		longitude = geoResponse[0].Lon
-	}
-
-	d.URL = fmt.Sprintf("http://api.openweathermap.org/data/2.5/weather?lat=%v&lon=%v&units=%s&appid=%s", latitude, longitude, units, apikey)
+	d.URL = fmt.Sprintf("https://api.openweathermap.org/data/2.5/weather?q=%s&units=%s&appid=%s", location, units, apikey)
 
 	body, err := d.env.HTTPRequest(d.URL, nil, httpTimeout)
 	if err != nil {
